"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: ClipDragDrop.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
import Parameters as wx


class Clipboard(Object):
    """"""

    def AddData(self):
        """"""
        pass

    def Clear(self):
        """"""
        pass

    def Close(self):
        """"""
        pass

    def Flush(self):
        """"""
        pass

    def GetData(self):
        """"""
        pass

    def IsOpened(self):
        """"""
        pass

    def IsSupported(self):
        """"""
        pass

    def Open(self):
        """"""
        pass

    def SetData(self):
        """"""
        pass

    def UsePrimarySelection(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DataFormat:
    """"""

    def GetId(self):
        """"""
        pass

    def GetType(self):
        """"""
        pass

    def SetId(self):
        """"""
        pass

    def SetType(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DataObject:
    """"""

    def GetAllFormats(self):
        """"""
        pass

    def GetDataHere(self):
        """"""
        pass

    def GetDataSize(self):
        """"""
        pass

    def GetFormatCount(self):
        """"""
        pass

    def GetPreferredFormat(self):
        """"""
        pass

    def IsSupportedFormat(self):
        """"""
        pass

    def SetData(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DataObjectComposite(DataObject):
    """"""

    def Add(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DataObjectSimple(DataObject):
    """"""

    def GetFormat(self):
        """"""
        pass

    def SetFormat(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PyDataObjectSimple(DataObjectSimple):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class BitmapDataObject(DataObjectSimple):
    """"""

    def GetBitmap(self):
        """"""
        pass

    def SetBitmap(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PyBitmapDataObject(BitmapDataObject):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class CustomDataObject(DataObjectSimple):
    """"""

    def GetData(self):
        """"""
        pass

    def GetSize(self):
        """"""
        pass

    def SetData(self):
        """"""
        pass

    def TakeData(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DragImage(Object):
    """"""

    def BeginDrag(self):
        """"""
        pass

    def BeginDrag2(self):
        """"""
        pass

    def EndDrag(self):
        """"""
        pass

    def GetImageRect(self):
        """"""
        pass

    def Hide(self):
        """"""
        pass

    def Move(self):
        """"""
        pass

    def RedrawImage(self):
        """"""
        pass

    def SetBackingBitmap(self):
        """"""
        pass

    def Show(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DropSource:
    """"""

    def DoDragDrop(self):
        """"""
        pass

    def GetDataObject(self):
        """"""
        pass

    def SetCursor(self):
        """"""
        pass

    def SetData(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass

    def base_GiveFeedback(self):
        """"""
        pass


class DropTarget:
    """"""

    def __init__(self):
        """"""
        pass


class PyDropTarget(DropTarget):
    """"""

    def GetData(self):
        """"""
        pass

    def GetDataObject(self):
        """"""
        pass

    def SetDataObject(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass

    def base_OnDragOver(self):
        """"""
        pass

    def base_OnDrop(self):
        """"""
        pass

    def base_OnEnter(self):
        """"""
        pass

    def base_OnLeave(self):
        """"""
        pass


class FileDataObject(DataObjectSimple):
    """"""

    def GetFilenames(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FileDropTarget(PyDropTarget):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass

    def base_OnData(self):
        """"""
        pass

    def base_OnDragOver(self):
        """"""
        pass

    def base_OnDrop(self):
        """"""
        pass

    def base_OnEnter(self):
        """"""
        pass

    def base_OnLeave(self):
        """"""
        pass


class TextDataObject(DataObjectSimple):
    """"""

    def GetText(self):
        """"""
        pass

    def GetTextLength(self):
        """"""
        pass

    def SetText(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PyTextDataObject(TextDataObject):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class TextDropTarget(PyDropTarget):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass

    def base_OnData(self):
        """"""
        pass

    def base_OnDragOver(self):
        """"""
        pass

    def base_OnDrop(self):
        """"""
        pass

    def base_OnEnter(self):
        """"""
        pass

    def base_OnLeave(self):
        """"""
        pass


class URLDataObject(DataObjectComposite):
    """"""

    def GetURL(self):
        """"""
        pass

    def SetURL(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass




# This file was created automatically by SWIG.
import htmlc

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *
import wx
class wxHtmlLinkInfoPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetHref(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlLinkInfo_GetHref,(self,) + _args, _kwargs)
        return val
    def GetTarget(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlLinkInfo_GetTarget,(self,) + _args, _kwargs)
        return val
    def GetEvent(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlLinkInfo_GetEvent,(self,) + _args, _kwargs)
        return val
    def GetHtmlCell(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlLinkInfo_GetHtmlCell,(self,) + _args, _kwargs)
        if val: val = wxHtmlCellPtr(val) 
        return val
    def SetEvent(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlLinkInfo_SetEvent,(self,) + _args, _kwargs)
        return val
    def SetHtmlCell(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlLinkInfo_SetHtmlCell,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlLinkInfo instance at %s>" % (self.this,)
class wxHtmlLinkInfo(wxHtmlLinkInfoPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlLinkInfo,_args,_kwargs)
        self.thisown = 1




class wxHtmlTagPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetName(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_GetName,(self,) + _args, _kwargs)
        return val
    def HasParam(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_HasParam,(self,) + _args, _kwargs)
        return val
    def GetParam(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_GetParam,(self,) + _args, _kwargs)
        return val
    def GetAllParams(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_GetAllParams,(self,) + _args, _kwargs)
        return val
    def HasEnding(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_HasEnding,(self,) + _args, _kwargs)
        return val
    def GetBeginPos(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_GetBeginPos,(self,) + _args, _kwargs)
        return val
    def GetEndPos1(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_GetEndPos1,(self,) + _args, _kwargs)
        return val
    def GetEndPos2(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTag_GetEndPos2,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlTag instance at %s>" % (self.this,)
class wxHtmlTag(wxHtmlTagPtr):
    def __init__(self,this):
        self.this = this




class wxHtmlParserPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetFS(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_SetFS,(self,) + _args, _kwargs)
        return val
    def GetFS(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_GetFS,(self,) + _args, _kwargs)
        return val
    def Parse(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_Parse,(self,) + _args, _kwargs)
        return val
    def InitParser(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_InitParser,(self,) + _args, _kwargs)
        return val
    def DoneParser(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_DoneParser,(self,) + _args, _kwargs)
        return val
    def DoParsing(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_DoParsing,(self,) + _args, _kwargs)
        return val
    def StopParsing(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_StopParsing,(self,) + _args, _kwargs)
        return val
    def AddTagHandler(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_AddTagHandler,(self,) + _args, _kwargs)
        return val
    def GetSource(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_GetSource,(self,) + _args, _kwargs)
        return val
    def PushTagHandler(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_PushTagHandler,(self,) + _args, _kwargs)
        return val
    def PopTagHandler(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlParser_PopTagHandler,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlParser instance at %s>" % (self.this,)
class wxHtmlParser(wxHtmlParserPtr):
    def __init__(self,this):
        self.this = this




class wxHtmlWinParserPtr(wxHtmlParserPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetDC(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetDC,(self,) + _args, _kwargs)
        return val
    def GetDC(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetDC,(self,) + _args, _kwargs)
        return val
    def GetCharHeight(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetCharHeight,(self,) + _args, _kwargs)
        return val
    def GetCharWidth(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetCharWidth,(self,) + _args, _kwargs)
        return val
    def GetWindow(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetWindow,(self,) + _args, _kwargs)
        return val
    def SetFonts(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetFonts,(self,) + _args, _kwargs)
        return val
    def GetContainer(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetContainer,(self,) + _args, _kwargs)
        if val: val = wxHtmlContainerCellPtr(val) 
        return val
    def OpenContainer(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_OpenContainer,(self,) + _args, _kwargs)
        if val: val = wxHtmlContainerCellPtr(val) 
        return val
    def SetContainer(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetContainer,(self,) + _args, _kwargs)
        if val: val = wxHtmlContainerCellPtr(val) 
        return val
    def CloseContainer(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_CloseContainer,(self,) + _args, _kwargs)
        if val: val = wxHtmlContainerCellPtr(val) 
        return val
    def GetFontSize(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetFontSize,(self,) + _args, _kwargs)
        return val
    def SetFontSize(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetFontSize,(self,) + _args, _kwargs)
        return val
    def GetFontBold(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetFontBold,(self,) + _args, _kwargs)
        return val
    def SetFontBold(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetFontBold,(self,) + _args, _kwargs)
        return val
    def GetFontItalic(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetFontItalic,(self,) + _args, _kwargs)
        return val
    def SetFontItalic(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetFontItalic,(self,) + _args, _kwargs)
        return val
    def GetFontUnderlined(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetFontUnderlined,(self,) + _args, _kwargs)
        return val
    def SetFontUnderlined(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetFontUnderlined,(self,) + _args, _kwargs)
        return val
    def GetFontFixed(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetFontFixed,(self,) + _args, _kwargs)
        return val
    def SetFontFixed(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetFontFixed,(self,) + _args, _kwargs)
        return val
    def GetAlign(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetAlign,(self,) + _args, _kwargs)
        return val
    def SetAlign(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetAlign,(self,) + _args, _kwargs)
        return val
    def GetLinkColor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetLinkColor,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def SetLinkColor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetLinkColor,(self,) + _args, _kwargs)
        return val
    def GetActualColor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetActualColor,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def SetActualColor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetActualColor,(self,) + _args, _kwargs)
        return val
    def SetLink(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_SetLink,(self,) + _args, _kwargs)
        return val
    def CreateCurrentFont(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_CreateCurrentFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) 
        return val
    def GetLink(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinParser_GetLink,(self,) + _args, _kwargs)
        if val: val = wxHtmlLinkInfoPtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxHtmlWinParser instance at %s>" % (self.this,)
class wxHtmlWinParser(wxHtmlWinParserPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlWinParser,_args,_kwargs)
        self.thisown = 1




class wxHtmlTagHandlerPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTagHandler__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def SetParser(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTagHandler_SetParser,(self,) + _args, _kwargs)
        return val
    def GetParser(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTagHandler_GetParser,(self,) + _args, _kwargs)
        if val: val = wxHtmlParserPtr(val) 
        return val
    def ParseInner(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlTagHandler_ParseInner,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlTagHandler instance at %s>" % (self.this,)
class wxHtmlTagHandler(wxHtmlTagHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlTagHandler,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxHtmlTagHandler)




class wxHtmlWinTagHandlerPtr(wxHtmlTagHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinTagHandler__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def SetParser(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinTagHandler_SetParser,(self,) + _args, _kwargs)
        return val
    def GetParser(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinTagHandler_GetParser,(self,) + _args, _kwargs)
        if val: val = wxHtmlWinParserPtr(val) 
        return val
    def ParseInner(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWinTagHandler_ParseInner,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlWinTagHandler instance at %s>" % (self.this,)
class wxHtmlWinTagHandler(wxHtmlWinTagHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlWinTagHandler,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxHtmlWinTagHandler)




class wxHtmlCellPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPosX(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetPosX,(self,) + _args, _kwargs)
        return val
    def GetPosY(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetPosY,(self,) + _args, _kwargs)
        return val
    def GetWidth(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetWidth,(self,) + _args, _kwargs)
        return val
    def GetHeight(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetHeight,(self,) + _args, _kwargs)
        return val
    def GetDescent(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetDescent,(self,) + _args, _kwargs)
        return val
    def GetLink(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetLink,(self,) + _args, _kwargs)
        if val: val = wxHtmlLinkInfoPtr(val) 
        return val
    def GetNext(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetNext,(self,) + _args, _kwargs)
        if val: val = wxHtmlCellPtr(val) 
        return val
    def GetParent(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_GetParent,(self,) + _args, _kwargs)
        if val: val = wxHtmlContainerCellPtr(val) 
        return val
    def SetLink(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_SetLink,(self,) + _args, _kwargs)
        return val
    def SetNext(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_SetNext,(self,) + _args, _kwargs)
        return val
    def SetParent(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_SetParent,(self,) + _args, _kwargs)
        return val
    def SetPos(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_SetPos,(self,) + _args, _kwargs)
        return val
    def Layout(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_Layout,(self,) + _args, _kwargs)
        return val
    def Draw(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_Draw,(self,) + _args, _kwargs)
        return val
    def DrawInvisible(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_DrawInvisible,(self,) + _args, _kwargs)
        return val
    def Find(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_Find,(self,) + _args, _kwargs)
        if val: val = wxHtmlCellPtr(val) 
        return val
    def AdjustPagebreak(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_AdjustPagebreak,(self,) + _args, _kwargs)
        return val
    def SetCanLiveOnPagebreak(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlCell_SetCanLiveOnPagebreak,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlCell instance at %s>" % (self.this,)
class wxHtmlCell(wxHtmlCellPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlCell,_args,_kwargs)
        self.thisown = 1




class wxHtmlWordCellPtr(wxHtmlCellPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxHtmlWordCell instance at %s>" % (self.this,)
class wxHtmlWordCell(wxHtmlWordCellPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlWordCell,_args,_kwargs)
        self.thisown = 1




class wxHtmlContainerCellPtr(wxHtmlCellPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def InsertCell(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_InsertCell,(self,) + _args, _kwargs)
        return val
    def SetAlignHor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetAlignHor,(self,) + _args, _kwargs)
        return val
    def GetAlignHor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_GetAlignHor,(self,) + _args, _kwargs)
        return val
    def SetAlignVer(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetAlignVer,(self,) + _args, _kwargs)
        return val
    def GetAlignVer(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_GetAlignVer,(self,) + _args, _kwargs)
        return val
    def SetIndent(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetIndent,(self,) + _args, _kwargs)
        return val
    def GetIndent(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_GetIndent,(self,) + _args, _kwargs)
        return val
    def GetIndentUnits(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_GetIndentUnits,(self,) + _args, _kwargs)
        return val
    def SetAlign(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetAlign,(self,) + _args, _kwargs)
        return val
    def SetWidthFloat(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetWidthFloat,(self,) + _args, _kwargs)
        return val
    def SetWidthFloatFromTag(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetWidthFloatFromTag,(self,) + _args, _kwargs)
        return val
    def SetMinHeight(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetMinHeight,(self,) + _args, _kwargs)
        return val
    def SetBackgroundColour(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetBackgroundColour,(self,) + _args, _kwargs)
        return val
    def GetBackgroundColour(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_GetBackgroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def SetBorder(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_SetBorder,(self,) + _args, _kwargs)
        return val
    def GetFirstCell(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlContainerCell_GetFirstCell,(self,) + _args, _kwargs)
        if val: val = wxHtmlCellPtr(val) 
        return val
    def __repr__(self):
        return "<C wxHtmlContainerCell instance at %s>" % (self.this,)
class wxHtmlContainerCell(wxHtmlContainerCellPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlContainerCell,_args,_kwargs)
        self.thisown = 1




class wxHtmlColourCellPtr(wxHtmlCellPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxHtmlColourCell instance at %s>" % (self.this,)
class wxHtmlColourCell(wxHtmlColourCellPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlColourCell,_args,_kwargs)
        self.thisown = 1




class wxHtmlFontCellPtr(wxHtmlCellPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxHtmlFontCell instance at %s>" % (self.this,)
class wxHtmlFontCell(wxHtmlFontCellPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlFontCell,_args,_kwargs)
        self.thisown = 1




class wxHtmlWidgetCellPtr(wxHtmlCellPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxHtmlWidgetCell instance at %s>" % (self.this,)
class wxHtmlWidgetCell(wxHtmlWidgetCellPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlWidgetCell,_args,_kwargs)
        self.thisown = 1




class wxHtmlFilterPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlFilter__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlFilter instance at %s>" % (self.this,)
class wxHtmlFilter(wxHtmlFilterPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlFilter,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxHtmlFilter)




class wxHtmlWindowPtr(wxScrolledWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_Create,(self,) + _args, _kwargs)
        return val
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def SetPage(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_SetPage,(self,) + _args, _kwargs)
        return val
    def LoadPage(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_LoadPage,(self,) + _args, _kwargs)
        return val
    def AppendToPage(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_AppendToPage,(self,) + _args, _kwargs)
        return val
    def GetOpenedPage(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_GetOpenedPage,(self,) + _args, _kwargs)
        return val
    def GetOpenedAnchor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_GetOpenedAnchor,(self,) + _args, _kwargs)
        return val
    def GetOpenedPageTitle(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_GetOpenedPageTitle,(self,) + _args, _kwargs)
        return val
    def SetRelatedFrame(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_SetRelatedFrame,(self,) + _args, _kwargs)
        return val
    def GetRelatedFrame(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_GetRelatedFrame,(self,) + _args, _kwargs)
        return val
    def SetRelatedStatusBar(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_SetRelatedStatusBar,(self,) + _args, _kwargs)
        return val
    def SetFonts(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_SetFonts,(self,) + _args, _kwargs)
        return val
    def SetTitle(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_SetTitle,(self,) + _args, _kwargs)
        return val
    def SetBorders(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_SetBorders,(self,) + _args, _kwargs)
        return val
    def ReadCustomization(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_ReadCustomization,(self,) + _args, _kwargs)
        return val
    def WriteCustomization(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_WriteCustomization,(self,) + _args, _kwargs)
        return val
    def HistoryBack(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_HistoryBack,(self,) + _args, _kwargs)
        return val
    def HistoryForward(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_HistoryForward,(self,) + _args, _kwargs)
        return val
    def HistoryCanBack(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_HistoryCanBack,(self,) + _args, _kwargs)
        return val
    def HistoryCanForward(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_HistoryCanForward,(self,) + _args, _kwargs)
        return val
    def HistoryClear(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_HistoryClear,(self,) + _args, _kwargs)
        return val
    def GetInternalRepresentation(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_GetInternalRepresentation,(self,) + _args, _kwargs)
        if val: val = wxHtmlContainerCellPtr(val) 
        return val
    def GetParser(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_GetParser,(self,) + _args, _kwargs)
        if val: val = wxHtmlWinParserPtr(val) 
        return val
    def ScrollToAnchor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_ScrollToAnchor,(self,) + _args, _kwargs)
        return val
    def HasAnchor(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_HasAnchor,(self,) + _args, _kwargs)
        return val
    def base_OnLinkClicked(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_base_OnLinkClicked,(self,) + _args, _kwargs)
        return val
    def base_OnSetTitle(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_base_OnSetTitle,(self,) + _args, _kwargs)
        return val
    def base_OnCellMouseHover(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_base_OnCellMouseHover,(self,) + _args, _kwargs)
        return val
    def base_OnCellClicked(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlWindow_base_OnCellClicked,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlWindow instance at %s>" % (self.this,)
class wxHtmlWindow(wxHtmlWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlWindow,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxHtmlWindow)
        self._setOORInfo(self)



def wxPreHtmlWindow(*_args,**_kwargs):
    val = wxHtmlWindowPtr(apply(htmlc.new_wxPreHtmlWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxHtmlDCRendererPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=htmlc.delete_wxHtmlDCRenderer):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetDC(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlDCRenderer_SetDC,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlDCRenderer_SetSize,(self,) + _args, _kwargs)
        return val
    def SetHtmlText(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlDCRenderer_SetHtmlText,(self,) + _args, _kwargs)
        return val
    def Render(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlDCRenderer_Render,(self,) + _args, _kwargs)
        return val
    def GetTotalHeight(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlDCRenderer_GetTotalHeight,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlDCRenderer instance at %s>" % (self.this,)
class wxHtmlDCRenderer(wxHtmlDCRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlDCRenderer,_args,_kwargs)
        self.thisown = 1




class wxHtmlPrintoutPtr(wxPrintoutPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetHtmlText(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlPrintout_SetHtmlText,(self,) + _args, _kwargs)
        return val
    def SetHtmlFile(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlPrintout_SetHtmlFile,(self,) + _args, _kwargs)
        return val
    def SetHeader(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlPrintout_SetHeader,(self,) + _args, _kwargs)
        return val
    def SetFooter(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlPrintout_SetFooter,(self,) + _args, _kwargs)
        return val
    def SetMargins(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlPrintout_SetMargins,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlPrintout instance at %s>" % (self.this,)
class wxHtmlPrintout(wxHtmlPrintoutPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlPrintout,_args,_kwargs)
        self.thisown = 1




class wxHtmlEasyPrintingPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=htmlc.delete_wxHtmlEasyPrinting):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def PreviewFile(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_PreviewFile,(self,) + _args, _kwargs)
        return val
    def PreviewText(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_PreviewText,(self,) + _args, _kwargs)
        return val
    def PrintFile(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_PrintFile,(self,) + _args, _kwargs)
        return val
    def PrintText(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_PrintText,(self,) + _args, _kwargs)
        return val
    def PrinterSetup(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_PrinterSetup,(self,) + _args, _kwargs)
        return val
    def PageSetup(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_PageSetup,(self,) + _args, _kwargs)
        return val
    def SetHeader(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_SetHeader,(self,) + _args, _kwargs)
        return val
    def SetFooter(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_SetFooter,(self,) + _args, _kwargs)
        return val
    def GetPrintData(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_GetPrintData,(self,) + _args, _kwargs)
        if val: val = wxPrintDataPtr(val) 
        return val
    def GetPageSetupData(self, *_args, **_kwargs):
        val = apply(htmlc.wxHtmlEasyPrinting_GetPageSetupData,(self,) + _args, _kwargs)
        if val: val = wxPageSetupDialogDataPtr(val) 
        return val
    def __repr__(self):
        return "<C wxHtmlEasyPrinting instance at %s>" % (self.this,)
class wxHtmlEasyPrinting(wxHtmlEasyPrintingPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlc.new_wxHtmlEasyPrinting,_args,_kwargs)
        self.thisown = 1






#-------------- FUNCTION WRAPPERS ------------------

wxHtmlWinParser_AddTagHandler = htmlc.wxHtmlWinParser_AddTagHandler

wxHtmlWindow_AddFilter = htmlc.wxHtmlWindow_AddFilter



#-------------- VARIABLE WRAPPERS ------------------

wxHTML_ALIGN_LEFT = htmlc.wxHTML_ALIGN_LEFT
wxHTML_ALIGN_CENTER = htmlc.wxHTML_ALIGN_CENTER
wxHTML_ALIGN_RIGHT = htmlc.wxHTML_ALIGN_RIGHT
wxHTML_ALIGN_BOTTOM = htmlc.wxHTML_ALIGN_BOTTOM
wxHTML_ALIGN_TOP = htmlc.wxHTML_ALIGN_TOP
wxHTML_CLR_FOREGROUND = htmlc.wxHTML_CLR_FOREGROUND
wxHTML_CLR_BACKGROUND = htmlc.wxHTML_CLR_BACKGROUND
wxHTML_UNITS_PIXELS = htmlc.wxHTML_UNITS_PIXELS
wxHTML_UNITS_PERCENT = htmlc.wxHTML_UNITS_PERCENT
wxHTML_INDENT_LEFT = htmlc.wxHTML_INDENT_LEFT
wxHTML_INDENT_RIGHT = htmlc.wxHTML_INDENT_RIGHT
wxHTML_INDENT_TOP = htmlc.wxHTML_INDENT_TOP
wxHTML_INDENT_BOTTOM = htmlc.wxHTML_INDENT_BOTTOM
wxHTML_INDENT_HORIZONTAL = htmlc.wxHTML_INDENT_HORIZONTAL
wxHTML_INDENT_VERTICAL = htmlc.wxHTML_INDENT_VERTICAL
wxHTML_INDENT_ALL = htmlc.wxHTML_INDENT_ALL
wxHTML_COND_ISANCHOR = htmlc.wxHTML_COND_ISANCHOR
wxHTML_COND_ISIMAGEMAP = htmlc.wxHTML_COND_ISIMAGEMAP
wxHTML_COND_USER = htmlc.wxHTML_COND_USER
wxHW_SCROLLBAR_NEVER = htmlc.wxHW_SCROLLBAR_NEVER
wxHW_SCROLLBAR_AUTO = htmlc.wxHW_SCROLLBAR_AUTO
wxHTML_OPEN = htmlc.wxHTML_OPEN
wxHTML_BLOCK = htmlc.wxHTML_BLOCK
wxHTML_REDIRECT = htmlc.wxHTML_REDIRECT
wxHTML_URL_PAGE = htmlc.wxHTML_URL_PAGE
wxHTML_URL_IMAGE = htmlc.wxHTML_URL_IMAGE
wxHTML_URL_OTHER = htmlc.wxHTML_URL_OTHER
wxPAGE_ODD = htmlc.wxPAGE_ODD
wxPAGE_EVEN = htmlc.wxPAGE_EVEN
wxPAGE_ALL = htmlc.wxPAGE_ALL


#-------------- USER INCLUDE -----------------------


# Stuff these names into the wx namespace so wxPyConstructObject can find them
import wx
wx.wxHtmlTagPtr             = wxHtmlTagPtr
wx.wxHtmlParserPtr          = wxHtmlParserPtr
wx.wxHtmlWinParserPtr       = wxHtmlWinParserPtr
wx.wxHtmlTagHandlerPtr      = wxHtmlTagHandlerPtr
wx.wxHtmlWinTagHandlerPtr   = wxHtmlWinTagHandlerPtr
wx.wxHtmlCellPtr            = wxHtmlCellPtr
wx.wxHtmlContainerCellPtr   = wxHtmlContainerCellPtr
wx.wxHtmlWidgetCellPtr      = wxHtmlWidgetCellPtr
wx.wxHtmlWindowPtr          = wxHtmlWindowPtr
wx.wxHtmlLinkInfoPtr        = wxHtmlLinkInfoPtr
wx.wxHtmlFilterPtr          = wxHtmlFilterPtr




"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Functions.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


def ArtProvider_GetBitmap():
    """"""
    pass

def ArtProvider_GetIcon():
    """"""
    pass

def ArtProvider_PopProvider():
    """"""
    pass

def ArtProvider_PushProvider():
    """"""
    pass

def ArtProvider_RemoveProvider():
    """"""
    pass

def BeginBusyCursor():
    """"""
    pass

def Bell():
    """"""
    pass

def BitmapFromBits():
    """"""
    pass

def BitmapFromIcon():
    """"""
    pass

def BitmapFromImage():
    """"""
    pass

def BitmapFromXPMData():
    """"""
    pass

def BufferedDCInternalBuffer():
    """"""
    pass

def Button_GetDefaultSize():
    """"""
    pass

def CallAfter(callable, *args, **kw):
    """Call the specified function after the current and pending event
    handlers have been completed.  This is also good for making GUI
    method calls from non-GUI threads."""
    pass

def Caret_GetBlinkTime():
    """"""
    pass

def Caret_SetBlinkTime():
    """"""
    pass

def ClientDisplayRect():
    """"""
    pass

def ColourDisplay():
    """"""
    pass

def ConfigBase_Create():
    """"""
    pass

def ConfigBase_DontCreateOnDemand():
    """"""
    pass

def ConfigBase_Get():
    """"""
    pass

def ConfigBase_Set():
    """"""
    pass

def CreateFileTipProvider():
    """"""
    pass

def CustomDataFormat():
    """"""
    pass

def DLG_PNT():
    """"""
    pass

def DLG_SZE():
    """"""
    pass

def DateSpan_Day():
    """"""
    pass

def DateSpan_Days():
    """"""
    pass

def DateSpan_Month():
    """"""
    pass

def DateSpan_Months():
    """"""
    pass

def DateSpan_Week():
    """"""
    pass

def DateSpan_Weeks():
    """"""
    pass

def DateSpan_Year():
    """"""
    pass

def DateSpan_Years():
    """"""
    pass

def DateTimeFromDMY():
    """"""
    pass

def DateTimeFromHMS():
    """"""
    pass

def DateTimeFromJDN():
    """"""
    pass

def DateTimeFromTimeT():
    """"""
    pass

def DateTime_ConvertYearToBC():
    """"""
    pass

def DateTime_GetAmPmStrings():
    """"""
    pass

def DateTime_GetBeginDST():
    """"""
    pass

def DateTime_GetCentury():
    """"""
    pass

def DateTime_GetCountry():
    """"""
    pass

def DateTime_GetCurrentMonth():
    """"""
    pass

def DateTime_GetCurrentYear():
    """"""
    pass

def DateTime_GetEndDST():
    """"""
    pass

def DateTime_GetMonthName():
    """"""
    pass

def DateTime_GetNumberOfDaysInMonth():
    """"""
    pass

def DateTime_GetNumberOfDaysinYear():
    """"""
    pass

def DateTime_GetWeekDayName():
    """"""
    pass

def DateTime_IsDSTApplicable():
    """"""
    pass

def DateTime_IsLeapYear():
    """"""
    pass

def DateTime_IsWestEuropeanCountry():
    """"""
    pass

def DateTime_Now():
    """"""
    pass

def DateTime_SetCountry():
    """"""
    pass

def DateTime_Today():
    """"""
    pass

def DateTime_UNow():
    """"""
    pass

def DirSelector():
    """"""
    pass

def DisplayDepth():
    """"""
    pass

def DisplaySize():
    """"""
    pass

def DisplaySizeMM():
    """"""
    pass

def DragIcon():
    """"""
    pass

def DragListItem():
    """"""
    pass

def DragString():
    """"""
    pass

def DragTreeItem():
    """"""
    pass

def EmptyBitmap():
    """"""
    pass

def EmptyIcon():
    """"""
    pass

def EmptyImage():
    """"""
    pass

def EnableTopLevelWindows():
    """"""
    pass

def EncodingConverter_GetAllEquivalents():
    """"""
    pass

def EncodingConverter_GetPlatformEquivalents():
    """"""
    pass

def EndBusyCursor():
    """"""
    pass

def Execute():
    """"""
    pass

def FileSelector():
    """"""
    pass

def FileSystem_AddHandler():
    """"""
    pass

def FileSystem_CleanUpHandlers():
    """"""
    pass

def FileTypeInfoSequence():
    """"""
    pass

def FileType_ExpandCommand():
    """"""
    pass

def FindWindowAtPoint():
    """"""
    pass

def FindWindowById(id, parent=wx.NULL):
    """"""
    pass

def FindWindowByLabel(label, parent=wx.NULL):
    """"""
    pass

def FindWindowByName(name, parent=wx.NULL):
    """"""
    pass

def FontFromNativeInfo():
    """"""
    pass

def FontMapper_Get():
    """"""
    pass

def FontMapper_GetDefaultConfigPath():
    """"""
    pass

def FontMapper_GetEncodingDescription():
    """"""
    pass

def FontMapper_GetEncodingName():
    """"""
    pass

def FontMapper_Set():
    """"""
    pass

def Font_GetDefaultEncoding():
    """"""
    pass

def Font_SetDefaultEncoding():
    """"""
    pass

def GenericFindWindowAtPoint():
    """"""
    pass

def GetAccelFromString():
    """"""
    pass

def GetActiveWindow():
    """"""
    pass

def GetApp():
    """"""
    pass

def GetClientDisplayRect():
    """"""
    pass

def GetCurrentId():
    """"""
    pass

def GetCurrentTime():
    """"""
    pass

def GetDisplayDepth():
    """"""
    pass

def GetDisplaySize():
    """"""
    pass

def GetDisplaySizeMM():
    """"""
    pass

def GetElapsedTime():
    """"""
    pass

def GetEmailAddress():
    """"""
    pass

def GetFullHostName():
    """"""
    pass

def GetHomeDir():
    """"""
    pass

def GetHostName():
    """"""
    pass

def GetLocalTime():
    """"""
    pass

def GetLocalTimeMillis():
    """"""
    pass

def GetLocale():
    """"""
    pass

def GetMousePosition():
    """"""
    pass

def GetNumberFromUser():
    """"""
    pass

def GetOsDescription():
    """"""
    pass

def GetOsVersion():
    """"""
    pass

def GetPasswordFromUser():
    """"""
    pass

def GetProcessId():
    """"""
    pass

def GetSingleChoice():
    """"""
    pass

def GetSingleChoiceIndex():
    """"""
    pass

def GetTextFromUser():
    """"""
    pass

def GetTopLevelParent():
    """"""
    pass

def GetTranslation():
    """"""
    pass

def GetUTCTime():
    """"""
    pass

def GetUserHome():
    """"""
    pass

def GetUserId():
    """"""
    pass

def GetUserName():
    """"""
    pass

def IconBundleFromFile():
    """"""
    pass

def IconBundleFromIcon():
    """"""
    pass

def IconFromBitmap():
    """"""
    pass

def IconFromXPMData():
    """"""
    pass

def ImageFromBitmap():
    """"""
    pass

def ImageFromData():
    """"""
    pass

def ImageFromMime():
    """"""
    pass

def ImageFromStream():
    """"""
    pass

def ImageFromStreamMime():
    """"""
    pass

def Image_AddHandler():
    """"""
    pass

def Image_CanRead():
    """"""
    pass

def Image_CanReadStream():
    """"""
    pass

def Image_GetImageCount():
    """"""
    pass

def Image_InsertHandler():
    """"""
    pass

def Image_RemoveHandler():
    """"""
    pass

def InitAllImageHandlers():
    """"""
    pass

def IntersectRect():
    """"""
    pass

def IsBusy():
    """"""
    pass

def IsDragResultOk():
    """"""
    pass

def LoadFileSelector():
    """"""
    pass

def Locale_AddCatalogLookupPathPrefix():
    """"""
    pass

def Locale_AddLanguage():
    """"""
    pass

def Locale_GetLanguageInfo():
    """"""
    pass

def Locale_GetSystemEncoding():
    """"""
    pass

def Locale_GetSystemEncodingName():
    """"""
    pass

def Locale_GetSystemLanguage():
    """"""
    pass

def LogDebug():
    """"""
    pass

def LogError():
    """"""
    pass

def LogFatalError():
    """"""
    pass

def LogGeneric():
    """"""
    pass

def LogInfo():
    """"""
    pass

def LogMessage():
    """"""
    pass

def LogStatus():
    """"""
    pass

def LogStatusFrame():
    """"""
    pass

def LogSysError():
    """"""
    pass

def LogTrace():
    """"""
    pass

def LogTraceMask():
    """"""
    pass

def LogVerbose():
    """"""
    pass

def LogWarning():
    """"""
    pass

def Log_AddTraceMask():
    """"""
    pass

def Log_ClearTraceMasks():
    """"""
    pass

def Log_DontCreateOnDemand():
    """"""
    pass

def Log_EnableLogging():
    """"""
    pass

def Log_FlushActive():
    """"""
    pass

def Log_GetActiveTarget():
    """"""
    pass

def Log_GetLogLevel():
    """"""
    pass

def Log_GetTimestamp():
    """"""
    pass

def Log_GetTraceMask():
    """"""
    pass

def Log_GetTraceMasks():
    """"""
    pass

def Log_IsAllowedTraceMask():
    """"""
    pass

def Log_IsEnabled():
    """"""
    pass

def Log_OnLog():
    """"""
    pass

def Log_RemoveTraceMask():
    """"""
    pass

def Log_Resume():
    """"""
    pass

def Log_SetActiveTarget():
    """"""
    pass

def Log_SetLogLevel():
    """"""
    pass

def Log_SetTimestamp():
    """"""
    pass

def Log_SetTraceMask():
    """"""
    pass

def Log_SetVerbose():
    """"""
    pass

def Log_Suspend():
    """"""
    pass

def MaskColour():
    """"""
    pass

def MemoryDCFromDC():
    """"""
    pass

def MemoryFSHandler_AddFile():
    """"""
    pass

def MemoryFSHandler_RemoveFile():
    """"""
    pass

def MenuItem_GetLabelFromText():
    """"""
    pass

def MessageBox():
    """"""
    pass

def MimeTypesManager_IsOfType():
    """"""
    pass

def MutexGuiEnter():
    """"""
    pass

def MutexGuiLeave():
    """"""
    pass

def NamedColour():
    """"""
    pass

def NamedColour():
    """"""
    pass

def NewEventType():
    """"""
    pass

def NewId():
    """"""
    pass

def Now():
    """"""
    pass

def NullFileTypeInfo():
    """"""
    pass

def Point2DDoubleCopy():
    """"""
    pass

def Point2DDoubleFromPoint():
    """"""
    pass

def PostEvent():
    """"""
    pass

def PostScriptDC_GetResolution():
    """"""
    pass

def PostScriptDC_SetResolution():
    """"""
    pass

def PreBitmapButton():
    """"""
    pass

def PreButton():
    """"""
    pass

def PreCheckBox():
    """"""
    pass

def PreCheckListBox():
    """"""
    pass

def PreChoice():
    """"""
    pass

def PreComboBox():
    """"""
    pass

def PreControl():
    """"""
    pass

def PreDialog():
    """"""
    pass

def PreDirFilterListCtrl():
    """"""
    pass

def PreFindReplaceDialog():
    """"""
    pass

def PreFrame():
    """"""
    pass

def PreGauge():
    """"""
    pass

def PreGenericDirCtrl():
    """"""
    pass

def PreListBox():
    """"""
    pass

def PreListCtrl():
    """"""
    pass

def PreListView():
    """"""
    pass

def PreMDIChildFrame():
    """"""
    pass

def PreMDIClientWindow():
    """"""
    pass

def PreMDIParentFrame():
    """"""
    pass

def PreMiniFrame():
    """"""
    pass

def PreNotebook():
    """"""
    pass

def PrePanel():
    """"""
    pass

def PrePopupTransientWindow():
    """"""
    pass

def PrePopupWindow():
    """"""
    pass

def PreRadioBox():
    """"""
    pass

def PreRadioButton():
    """"""
    pass

def PreSashLayoutWindow():
    """"""
    pass

def PreSashWindow():
    """"""
    pass

def PreScrollBar():
    """"""
    pass

def PreScrolledWindow():
    """"""
    pass

def PreSingleInstanceChecker():
    """"""
    pass

def PreSlider():
    """"""
    pass

def PreSpinButton():
    """"""
    pass

def PreSpinCtrl():
    """"""
    pass

def PreSplitterWindow():
    """"""
    pass

def PreStaticBitmap():
    """"""
    pass

def PreStaticBox():
    """"""
    pass

def PreStaticLine():
    """"""
    pass

def PreStaticText():
    """"""
    pass

def PreStatusBar():
    """"""
    pass

def PreTextCtrl():
    """"""
    pass

def PreToggleButton():
    """"""
    pass

def PreToolBar():
    """"""
    pass

def PreToolBarSimple():
    """"""
    pass

def PreTopLevelWindow():
    """"""
    pass

def PreTreeCtrl():
    """"""
    pass

def PreWindow():
    """"""
    pass

def Process_Exists():
    """"""
    pass

def Process_Kill():
    """"""
    pass

def Process_Open():
    """"""
    pass

def PyTypeCast(obj, typeStr):
    """This helper function will take a wxPython object and convert it
    to another wxPython object type.  This will not be able to create
    objects that are derived from wxPython classes by the user, only
    those that are actually part of wxPython and directly corespond to
    C++ objects.

    This is useful in situations where some method returns a generic
    type such as wxWindow, but you know that it is actually some
    derived type such as a TextCtrl.  You can't call TextCtrl
    specific methods on a Window object, but you can use this
    function to create a TextCtrl object that will pass the same
    pointer to the C++ code.  You use it like this:

       textCtrl = PyTypeCast(window, "TextCtrl")

    WARNING:  Using this function to type cast objects into types that
              they are not is not recommended and is likely to cause
              your program to crash...  Hard."""
    pass

def Py_isinstance(obj, klasses):
    """An isinstance for Python < 2.2 that can check a sequence of
    class objects like the one in 2.2 can."""
    pass

def RegionFromPoints():
    """"""
    pass

def RegisterId():
    """"""
    pass

## def RunLater(callable, *args, **kw):
##     """An alias for CallAfter."""
##     pass

RunLater = CallAfter

def SafeShowMessage():
    """"""
    pass

def SafeYield():
    """"""
    pass

def SaveFileSelector():
    """"""
    pass

def SetCursor():
    """"""
    pass

def Shell():
    """"""
    pass

def ShowTip():
    """"""
    pass

def Shutdown():
    """"""
    pass

def Sleep():
    """"""
    pass

def StartTimer():
    """"""
    pass

def StockCursor():
    """"""
    pass

def StripMenuCodes():
    """"""
    pass

def SysErrorCode():
    """"""
    pass

def SysErrorMsg():
    """"""
    pass

def SystemSettings_GetColour():
    """"""
    pass

def SystemSettings_GetFont():
    """"""
    pass

def SystemSettings_GetMetric():
    """"""
    pass

def SystemSettings_GetScreenType():
    """"""
    pass

def SystemSettings_GetColour():
    """"""
    pass

def SystemSettings_GetFont():
    """"""
    pass

def SystemSettings_GetMetric():
    """"""
    pass

def SystemSettings_HasFeature():
    """"""
    pass

def SystemSettings_SetScreenType():
    """"""
    pass

def TextAttr_Combine():
    """"""
    pass

def Thread_IsMain():
    """"""
    pass

def TimeSpan_Day():
    """"""
    pass

def TimeSpan_Days():
    """"""
    pass

def TimeSpan_Hour():
    """"""
    pass

def TimeSpan_Hours():
    """"""
    pass

def TimeSpan_Minute():
    """"""
    pass

def TimeSpan_Minutes():
    """"""
    pass

def TimeSpan_Second():
    """"""
    pass

def TimeSpan_Seconds():
    """"""
    pass

def TimeSpan_Week():
    """"""
    pass

def TimeSpan_Weeks():
    """"""
    pass

def ToolTip_Enable():
    """"""
    pass

def ToolTip_SetDelay():
    """"""
    pass

def Usleep():
    """"""
    pass

def Validator_IsSilent():
    """"""
    pass

def Validator_SetBellOnError():
    """"""
    pass

def WakeUpIdle():
    """"""
    pass

def WaveData():
    """"""
    pass

def Window_FindFocus():
    """"""
    pass

def Window_GetCapture():
    """"""
    pass

def Window_NewControlId():
    """"""
    pass

def Window_NextControlId():
    """"""
    pass

def Window_PrevControlId():
    """"""
    pass

def Yield():
    """"""
    pass

def YieldIfNeeded():
    """"""
    pass



# This file was created automatically by SWIG.
import dllwidget_c

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *
class wxDllWidgetPtr(wxPanelPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Ok(self, *_args, **_kwargs):
        val = apply(dllwidget_c.wxDllWidget_Ok,(self,) + _args, _kwargs)
        return val
    def SendCommand(self, *_args, **_kwargs):
        val = apply(dllwidget_c.wxDllWidget_SendCommand,(self,) + _args, _kwargs)
        return val
    def GetWidgetWindow(self, *_args, **_kwargs):
        val = apply(dllwidget_c.wxDllWidget_GetWidgetWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDllWidget instance at %s>" % (self.this,)
class wxDllWidget(wxDllWidgetPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(dllwidget_c.new_wxDllWidget,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------

wxDllWidget_GetDllExt = dllwidget_c.wxDllWidget_GetDllExt



#-------------- VARIABLE WRAPPERS ------------------




#----------------------------------------------------------------------
# Name:        wxPython.lib.rcsizer
# Purpose:     RowColSizer:
#
# Author:      Robin Dunn, adapted from code by Niki Spahiev
#
# Created:     26-Feb-2002
# RCS-ID:      $Id: rcsizer.py,v 1.4 2002/05/27 17:54:45 RD Exp $
# Copyright:   (c) 2002 by Total Control Software
# Licence:     wxWindows license
#----------------------------------------------------------------------

"""
A pure-Python wxSizer that lays out items in a grid similar to
wxFlexGridSizer but item position is not implicit but explicitly
specified by row and col, and row/col spanning is supported.

Adapted from code by Niki Spahiev.

If anyone is interested, it would be nice to have this ported to C++.
"""



from wxPython.wx import *
import operator

#----------------------------------------------------------------------

class RowColSizer(wxPySizer):

    # default sizes for cells with no item
    col_w = 10
    row_h = 22

    def __init__(self):
        wxPySizer.__init__(self)
        self.growableRows = []
        self.growableCols = []


    def AddGrowableRow(self, idx):
        self.growableRows.append(idx)

    def AddGrowableCol(self, idx):
        self.growableCols.append(idx)



    #--------------------------------------------------
    def Add(self, item, option=0, flag=0, border=0,
            row=-1, col=-1,       # row, col and spanning can be specified individually...
            rowspan=1, colspan=1,
            pos=None, size=None,  # or as tuples (row,col) and (rowspan,colspan)
            ):

        if pos is not None:
            row, col = pos
        if size is not None:
            rowspan, colspan = size

        assert row != -1, "Row must be specified"
        assert col != -1, "Column must be specified"

        # Do I really want to do this?  Probably not...
        #if rowspan > 1 or colspan > 1:
        #    flag = flag | wxEXPAND

        wxPySizer.Add(self, item, option, flag, border,
                      userData=(row, col, row+rowspan, col+colspan))

    #AddWindow = Add
    #AddSizer  = Add

    def AddSpacer(self, width, height, option=0, flag=0, border=0,
                  row=-1, col=-1,
                  rowspan=1, colspan=1,
                  pos=None, size=None,
                  ):
        if pos is not None:
            row, col = pos
        if size is not None:
            rowspan, colspan = size

        assert row != -1, "Row must be specified"
        assert col != -1, "Column must be specified"

        wxPySizer.AddSpacer(self, width, height, option, flag, border,
                            userData=(row, col, row+rowspan, col+colspan))

    #--------------------------------------------------
    def _add( self, size, dim ):
        r, c, r2, c2 = dim   # unpack coords and spanning

        # are the widths and heights lists long enough?
        if r2 > len(self.rowHeights):
            x = [self.row_h] * (r2-len(self.rowHeights))
            self.rowHeights.extend( x )
        if c2 > len(self.colWidths):
            x = [self.col_w] * (c2-len(self.colWidths))
            self.colWidths.extend( x )

        # set the widths and heights lists for this item
        scale = (r2 - r)
        for i in range(r, r2):
            self.rowHeights[i] = max( self.rowHeights[i], size.height / scale )
        scale = (c2 - c)
        for i in range(c, c2):
            self.colWidths[i] = max( self.colWidths[i], size.width / scale )


    #--------------------------------------------------
    def CalcMin( self ):
        self.rowHeights = []
        self.colWidths = []

        items = self.GetChildren()
        if not items:
            return wxSize(10, 10)

        for item in items:
            self._add( item.CalcMin(), item.GetUserData() )

        size = wxSize( reduce( operator.add, self.colWidths),
                       reduce( operator.add, self.rowHeights) )
        return size


    #--------------------------------------------------
    def RecalcSizes( self ):
        # save current dimensions, etc.
        curWidth  = self.GetSize().width
        curHeight = self.GetSize().height
        px = self.GetPosition().x
        py = self.GetPosition().y
        minWidth  = self.CalcMin().width
        minHeight = self.CalcMin().height

        # Check for growables
        if self.growableRows and curHeight > minHeight:
            delta = (curHeight - minHeight) / len(self.growableRows)
            extra = (curHeight - minHeight) % len(self.growableRows)
            for idx in self.growableRows:
                self.rowHeights[idx] += delta
            self.rowHeights[self.growableRows[0]] += extra

        if self.growableCols and curWidth > minWidth:
            delta = (curWidth - minWidth) / len(self.growableCols)
            extra = (curWidth - minWidth) % len(self.growableCols)
            for idx in self.growableCols:
                self.colWidths[idx] += delta
            self.colWidths[self.growableCols[0]] += extra

        rpos = [0] * len(self.rowHeights)
        cpos = [0] * len(self.colWidths)

        for i in range(len(self.rowHeights)):
            height = self.rowHeights[i]
            rpos[i] = py
            py += height

        for i in range(len(self.colWidths)):
            width = self.colWidths[i]
            cpos[i] = px
            px += width

        # iterate children and set dimensions...
        for item in self.GetChildren():
            r, c, r2, c2 = item.GetUserData()
            width = reduce( operator.add, self.colWidths[c:c2] )
            height = reduce( operator.add, self.rowHeights[r:r2] )
            self.SetItemBounds( item, cpos[c], rpos[r], width, height )


    #--------------------------------------------------
    def SetItemBounds(self, item, x, y, w, h):
        # calculate the item's actual size and position within
        # its grid cell
        ipt = wxPoint(x, y)
        isz = item.CalcMin()
        flag = item.GetFlag()

        if flag & wxEXPAND or flag & wxSHAPED:
            isz = wxSize(w, h)
        else:
            if flag & wxALIGN_CENTER_HORIZONTAL:
                ipt.x = x + (w - isz.width) / 2
            elif flag & wxALIGN_RIGHT:
                ipt.x = x + (w - isz.width)

            if flag & wxALIGN_CENTER_VERTICAL:
                ipt.y = y + (h - isz.height) / 2
            elif flag & wxALIGN_BOTTOM:
                ipt.y = y + (h - isz.height)

        item.SetDimension(ipt, isz)


#----------------------------------------------------------------------
#----------------------------------------------------------------------






"""
This is a port of Konrad Hinsen's tkPlotCanvas.py plotting module.
After thinking long and hard I came up with the name "wxPlotCanvas.py".

This file contains two parts; first the re-usable library stuff, then, after
a "if __name__=='__main__'" test, a simple frame and a few default plots
for testing.

Harm van der Heijden, feb 1999

Original comment follows below:
# This module defines a plot widget for Tk user interfaces.
# It supports only elementary line plots at the moment.
# See the example at the end for documentation...
#
# Written by Konrad Hinsen <hinsen@cnrs-orleans.fr>
# With contributions from RajGopal Srinivasan <raj@cherubino.med.jhmi.edu>
# Last revision: 1998-7-28
#
"""

from wxPython import wx

# Not everybody will have Numeric, so let's be cool about it...
try:
    import Numeric
except:
    # bummer!
    msg = """This module requires the Numeric module, which could not be
imported.  It probably is not installed (it's not part of the standard
Python distribution). See the Python site (http://www.python.org) for
information on downloading source or binaries."""

    if wx.wxPlatform == '__WXMSW__':
        d = wx.wxMessageDialog(wx.NULL, msg, "Numeric not found")
        if d.ShowModal() == wx.wxID_CANCEL:
            d = wx.wxMessageDialog(wx.NULL, "I kid you not! Pressing Cancel won't help you!", "Not a joke", wx.wxOK)
            d.ShowModal()
    else:
        print msg
    raise ImportError

#
# Plotting classes...
#
class PolyPoints:

    def __init__(self, points, attr):
        self.points = Numeric.array(points)
        self.scaled = self.points
        self.attributes = {}
        for name, value in self._attributes.items():
            try:
                value = attr[name]
            except KeyError: pass
            self.attributes[name] = value

    def boundingBox(self):
        return Numeric.minimum.reduce(self.points), \
               Numeric.maximum.reduce(self.points)

    def scaleAndShift(self, scale=1, shift=0):
        self.scaled = scale*self.points+shift


class PolyLine(PolyPoints):

    def __init__(self, points, **attr):
        PolyPoints.__init__(self, points, attr)

    _attributes = {'color': 'black',
                   'width': 1}

    def draw(self, dc):
        color = self.attributes['color']
        width = self.attributes['width']
        arguments = []
        dc.SetPen(wx.wxPen(wx.wxNamedColour(color), width))
        dc.DrawLines(map(tuple,self.scaled))


class PolyMarker(PolyPoints):

    def __init__(self, points, **attr):

        PolyPoints.__init__(self, points, attr)

    _attributes = {'color': 'black',
                   'width': 1,
                   'fillcolor': None,
                   'size': 2,
                   'fillstyle': wx.wxSOLID,
                   'outline': 'black',
                   'marker': 'circle'}

    def draw(self, dc):
        color = self.attributes['color']
        width = self.attributes['width']
        size = self.attributes['size']
        fillcolor = self.attributes['fillcolor']
        fillstyle = self.attributes['fillstyle']
        marker = self.attributes['marker']

        dc.SetPen(wx.wxPen(wx.wxNamedColour(color),width))
        if fillcolor:
            dc.SetBrush(wx.wxBrush(wx.wxNamedColour(fillcolor),fillstyle))
        else:
            dc.SetBrush(wx.wxBrush(wx.wxNamedColour('black'), wx.wxTRANSPARENT))

        self._drawmarkers(dc, self.scaled, marker, size)

    def _drawmarkers(self, dc, coords, marker,size=1):
        f = eval('self._' +marker)
        for xc, yc in coords:
            f(dc, xc, yc, size)

    def _circle(self, dc, xc, yc, size=1):
        dc.DrawEllipse(xc-2.5*size,yc-2.5*size,5.*size,5.*size)

    def _dot(self, dc, xc, yc, size=1):
        dc.DrawPoint(xc,yc)

    def _square(self, dc, xc, yc, size=1):
        dc.DrawRectangle(xc-2.5*size,yc-2.5*size,5.*size,5.*size)

    def _triangle(self, dc, xc, yc, size=1):
        dc.DrawPolygon([(-0.5*size*5,0.2886751*size*5),
                       (0.5*size*5,0.2886751*size*5),
                       (0.0,-0.577350*size*5)],xc,yc)

    def _triangle_down(self, dc, xc, yc, size=1):
        dc.DrawPolygon([(-0.5*size*5,-0.2886751*size*5),
                       (0.5*size*5,-0.2886751*size*5),
                       (0.0,0.577350*size*5)],xc,yc)

    def _cross(self, dc, xc, yc, size=1):
        dc.DrawLine(xc-2.5*size,yc-2.5*size,xc+2.5*size,yc+2.5*size)
        dc.DrawLine(xc-2.5*size,yc+2.5*size,xc+2.5*size,yc-2.5*size)

    def _plus(self, dc, xc, yc, size=1):
        dc.DrawLine(xc-2.5*size,yc,xc+2.5*size,yc)
        dc.DrawLine(xc,yc-2.5*size,xc,yc+2.5*size)

class PlotGraphics:

    def __init__(self, objects):
        self.objects = objects

    def boundingBox(self):
        p1, p2 = self.objects[0].boundingBox()
        for o in self.objects[1:]:
            p1o, p2o = o.boundingBox()
            p1 = Numeric.minimum(p1, p1o)
            p2 = Numeric.maximum(p2, p2o)
        return p1, p2

    def scaleAndShift(self, scale=1, shift=0):
        for o in self.objects:
            o.scaleAndShift(scale, shift)

    def draw(self, canvas):
        for o in self.objects:
            o.draw(canvas)

    def __len__(self):
        return len(self.objects)

    def __getitem__(self, item):
        return self.objects[item]


class PlotCanvas(wx.wxWindow):

    def __init__(self, parent, id=-1,
                 pos = wx.wxDefaultPosition, size = wx.wxDefaultSize,
                 style = 0, name = 'plotCanvas'):
        wx.wxWindow.__init__(self, parent, id, pos, size, style, name)
        self.border = (1,1)
        self.SetClientSizeWH(400,400)
        self.SetBackgroundColour(wx.wxNamedColour("white"))

        wx.EVT_SIZE(self,self.reconfigure)
        wx.EVT_PAINT(self, self.OnPaint)
        self._setsize()
        self.last_draw = None
#       self.font = self._testFont(font)

    def OnPaint(self, event):
        pdc = wx.wxPaintDC(self)
        if self.last_draw is not None:
            apply(self.draw, self.last_draw + (pdc,))

    def reconfigure(self, event):
        (new_width,new_height) = self.GetClientSizeTuple()
        if new_width == self.width and new_height == self.height:
            return
        self._setsize()
        # self.redraw()

    def _testFont(self, font):
        if font is not None:
            bg = self.canvas.cget('background')
            try:
                item = CanvasText(self.canvas, 0, 0, anchor=NW,
                                  text='0', fill=bg, font=font)
                self.canvas.delete(item)
            except TclError:
                font = None
        return font

    def _setsize(self):
        (self.width,self.height) = self.GetClientSizeTuple();
        self.plotbox_size = 0.97*Numeric.array([self.width, -self.height])
        xo = 0.5*(self.width-self.plotbox_size[0])
        yo = self.height-0.5*(self.height+self.plotbox_size[1])
        self.plotbox_origin = Numeric.array([xo, yo])

    def draw(self, graphics, xaxis = None, yaxis = None, dc = None):
        if dc == None: dc = wx.wxClientDC(self)
        dc.BeginDrawing()
        dc.Clear()
        self.last_draw = (graphics, xaxis, yaxis)
        p1, p2 = graphics.boundingBox()
        xaxis = self._axisInterval(xaxis, p1[0], p2[0])
        yaxis = self._axisInterval(yaxis, p1[1], p2[1])
        text_width = [0., 0.]
        text_height = [0., 0.]
        if xaxis is not None:
            p1[0] = xaxis[0]
            p2[0] = xaxis[1]
            xticks = self._ticks(xaxis[0], xaxis[1])
            bb = dc.GetTextExtent(xticks[0][1])
            text_height[1] = bb[1]
            text_width[0] = 0.5*bb[0]
            bb = dc.GetTextExtent(xticks[-1][1])
            text_width[1] = 0.5*bb[0]
        else:
            xticks = None
        if yaxis is not None:
            p1[1] = yaxis[0]
            p2[1] = yaxis[1]
            yticks = self._ticks(yaxis[0], yaxis[1])
            for y in yticks:
                bb = dc.GetTextExtent(y[1])
                text_width[0] = max(text_width[0],bb[0])
            h = 0.5*bb[1]
            text_height[0] = h
            text_height[1] = max(text_height[1], h)
        else:
            yticks = None
        text1 = Numeric.array([text_width[0], -text_height[1]])
        text2 = Numeric.array([text_width[1], -text_height[0]])
        scale = (self.plotbox_size-text1-text2) / (p2-p1)
        shift = -p1*scale + self.plotbox_origin + text1
        self._drawAxes(dc, xaxis, yaxis, p1, p2,
                       scale, shift, xticks, yticks)
        graphics.scaleAndShift(scale, shift)
        graphics.draw(dc)
        dc.EndDrawing()

    def _axisInterval(self, spec, lower, upper):
        if spec is None:
            return None
        if spec == 'minimal':
            if lower == upper:
                return lower-0.5, upper+0.5
            else:
                return lower, upper
        if spec == 'automatic':
            range = upper-lower
            if range == 0.:
                return lower-0.5, upper+0.5
            log = Numeric.log10(range)
            power = Numeric.floor(log)
            fraction = log-power
            if fraction <= 0.05:
                power = power-1
            grid = 10.**power
            lower = lower - lower % grid
            mod = upper % grid
            if mod != 0:
                upper = upper - mod + grid
            return lower, upper
        if type(spec) == type(()):
            lower, upper = spec
            if lower <= upper:
                return lower, upper
            else:
                return upper, lower
        raise ValueError, str(spec) + ': illegal axis specification'

    def _drawAxes(self, dc, xaxis, yaxis,
                  bb1, bb2, scale, shift, xticks, yticks):
        dc.SetPen(wx.wxPen(wx.wxNamedColour('BLACK'),1))
        if xaxis is not None:
            lower, upper = xaxis
            text = 1
            for y, d in [(bb1[1], -3), (bb2[1], 3)]:
                p1 = scale*Numeric.array([lower, y])+shift
                p2 = scale*Numeric.array([upper, y])+shift
                dc.DrawLine(p1[0],p1[1],p2[0],p2[1])
                for x, label in xticks:
                    p = scale*Numeric.array([x, y])+shift
                    dc.DrawLine(p[0],p[1],p[0],p[1]+d)
                    if text:
                        dc.DrawText(label,p[0],p[1])
                text = 0

        if yaxis is not None:
            lower, upper = yaxis
            text = 1
            h = dc.GetCharHeight()
            for x, d in [(bb1[0], -3), (bb2[0], 3)]:
                p1 = scale*Numeric.array([x, lower])+shift
                p2 = scale*Numeric.array([x, upper])+shift
                dc.DrawLine(p1[0],p1[1],p2[0],p2[1])
                for y, label in yticks:
                    p = scale*Numeric.array([x, y])+shift
                    dc.DrawLine(p[0],p[1],p[0]-d,p[1])
                    if text:
                        dc.DrawText(label,p[0]-dc.GetTextExtent(label)[0],
                                    p[1]-0.5*h)
                text = 0

    def _ticks(self, lower, upper):
        ideal = (upper-lower)/7.
        log = Numeric.log10(ideal)
        power = Numeric.floor(log)
        fraction = log-power
        factor = 1.
        error = fraction
        for f, lf in self._multiples:
            e = Numeric.fabs(fraction-lf)
            if e < error:
                error = e
                factor = f
        grid = factor * 10.**power
        if power > 3 or power < -3:
            format = '%+7.0e'
        elif power >= 0:
            digits = max(1, int(power))
            format = '%' + `digits`+'.0f'
        else:
            digits = -int(power)
            format = '%'+`digits+2`+'.'+`digits`+'f'
        ticks = []
        t = -grid*Numeric.floor(-lower/grid)
        while t <= upper:
            ticks.append( (t, format % (t,)) )
            t = t + grid
        return ticks

    _multiples = [(2., Numeric.log10(2.)), (5., Numeric.log10(5.))]

    def redraw(self,dc=None):
        if self.last_draw is not None:
            apply(self.draw, self.last_draw + (dc,))

    def clear(self):
        self.canvas.delete('all')

#---------------------------------------------------------------------------
# if running standalone...
#
#     ...a sample implementation using the above
#


if __name__ == '__main__':
    def _InitObjects():
        # 100 points sin function, plotted as green circles
        data1 = 2.*Numeric.pi*Numeric.arange(200)/200.
        data1.shape = (100, 2)
        data1[:,1] = Numeric.sin(data1[:,0])
        markers1 = PolyMarker(data1, color='green', marker='circle',size=1)

        # 50 points cos function, plotted as red line
        data1 = 2.*Numeric.pi*Numeric.arange(100)/100.
        data1.shape = (50,2)
        data1[:,1] = Numeric.cos(data1[:,0])
        lines = PolyLine(data1, color='red')

        # A few more points...
        pi = Numeric.pi
        markers2 = PolyMarker([(0., 0.), (pi/4., 1.), (pi/2, 0.),
                              (3.*pi/4., -1)], color='blue',
                              fillcolor='green', marker='cross')

        return PlotGraphics([markers1, lines, markers2])


    class AppFrame(wx.wxFrame):
        def __init__(self, parent, id, title):
            wx.wxFrame.__init__(self, parent, id, title,
                                wx.wxPyDefaultPosition, wx.wxSize(400, 400))

            # Now Create the menu bar and items
            self.mainmenu = wx.wxMenuBar()

            menu = wx.wxMenu()
            menu.Append(200, '&Print...', 'Print the current plot')
            wx.EVT_MENU(self, 200, self.OnFilePrint)
            menu.Append(209, 'E&xit', 'Enough of this already!')
            wx.EVT_MENU(self, 209, self.OnFileExit)
            self.mainmenu.Append(menu, '&File')

            menu = wx.wxMenu()
            menu.Append(210, '&Draw', 'Draw plots')
            wx.EVT_MENU(self,210,self.OnPlotDraw)
            menu.Append(211, '&Redraw', 'Redraw plots')
            wx.EVT_MENU(self,211,self.OnPlotRedraw)
            menu.Append(212, '&Clear', 'Clear canvas')
            wx.EVT_MENU(self,212,self.OnPlotClear)
            self.mainmenu.Append(menu, '&Plot')

            menu = wx.wxMenu()
            menu.Append(220, '&About', 'About this thing...')
            wx.EVT_MENU(self, 220, self.OnHelpAbout)
            self.mainmenu.Append(menu, '&Help')

            self.SetMenuBar(self.mainmenu)

            # A status bar to tell people what's happening
            self.CreateStatusBar(1)

            self.client = PlotCanvas(self)

        def OnFilePrint(self, event):
            d = wx.wxMessageDialog(self,
"""As of this writing, printing support in wxPython is shaky at best.
Are you sure you want to do this?""", "Danger!", wx.wxYES_NO)
            if d.ShowModal() == wx.wxID_YES:
                psdc = wx.wxPostScriptDC("out.ps", wx.True, self)
                self.client.redraw(psdc)

        def OnFileExit(self, event):
            self.Close()

        def OnPlotDraw(self, event):
            self.client.draw(_InitObjects(),'automatic','automatic');

        def OnPlotRedraw(self,event):
            self.client.redraw()

        def OnPlotClear(self,event):
            self.client.last_draw = None
            dc = wx.wxClientDC(self.client)
            dc.Clear()

        def OnHelpAbout(self, event):
            about = wx.wxMessageDialog(self, __doc__, "About...", wx.wxOK)
            about.ShowModal()



    class MyApp(wx.wxApp):
        def OnInit(self):
            frame = AppFrame(wx.NULL, -1, "wxPlotCanvas")
            frame.Show(wx.True)
            self.SetTopWindow(frame)
            return wx.True


    app = MyApp(0)
    app.MainLoop()




#----------------------------------------------------------------------------



#----------------------------------------------------------------------------
# Name:         calendar.py
# Purpose:      Calendar display control
#
# Author:       Lorne White (email: lorne.white@telusplanet.net)
#
# Created:
# Version       0.92
# Date:         Nov 26, 2001
# Licence:      wxWindows license
#----------------------------------------------------------------------------

from wxPython.wx import *

from CDate import *


CalDays = [6, 0, 1, 2, 3, 4, 5]
AbrWeekday = {6:"Sun", 0:"Mon", 1:"Tue", 2:"Wed", 3:"Thu", 4:"Fri", 5:"Sat"}
_MIDSIZE = 180

BusCalDays = [0, 1, 2, 3, 4, 5, 6]

# calendar drawing routing

def GetMonthList():
    monthlist = []
    for i in range(13):
        name = Month[i]
        if name != None:
            monthlist.append(name)
    return monthlist

class CalDraw:
    def __init__(self, parent):
        self.pwidth = 1
        self.pheight = 1
        try:
            self.scale = parent.scale
        except:
            self.scale = 1

        self.DefParms()

    def DefParms(self):
        self.num_auto = True       # auto scale of the cal number day size
        self.num_size = 12          # default size of calendar if no auto size
        self.max_num_size = 12     # maximum size for calendar number

        self.num_align_horz = wxALIGN_CENTRE    # alignment of numbers
        self.num_align_vert = wxALIGN_CENTRE
        self.num_indent_horz = 0     # points indent from position, used to offset if not centered
        self.num_indent_vert = 0

        self.week_auto = True       # auto scale of week font text
        self.week_size = 10
        self.max_week_size = 12

        self.grid_color = 'BLACK'       # grid and selection colors
        self.back_color = 'WHITE'
        self.sel_color = 'RED'

        self.high_color = 'LIGHT BLUE'
        self.border_color = 'BLACK'
        self.week_color = 'LIGHT GREY'

        self.week_font_color = 'BLACK'      # font colors
        self.day_font_color = 'BLACK'

        self.font = wxSWISS
        self.bold = wxNORMAL

        self.hide_title = False
        self.hide_grid = False
        self.outer_border = True

        self.title_offset = 0
        self.cal_week_scale = 0.7
        self.show_weekend = False
        self.cal_type = "NORMAL"

    def SetWeekColor(self, font_color, week_color):     # set font and background color for week title
        self.week_font_color = font_color
        self.week_color = week_color

    def SetSize(self, size):
        self.set_sizew = size.width
        self.set_sizeh = size.height

    def InitValues(self):       # default dimensions of various elements of the calendar
        self.rg = {}
        self.cal_sel = {}
        self.set_cy_st = 0      # start position
        self.set_cx_st = 0

        self.set_y_mrg = 15      # start of vertical draw default
        self.set_x_mrg = 10
        self.set_y_end = 10

    def SetPos(self, xpos, ypos):
        self.set_cx_st = xpos
        self.set_cy_st = ypos

    def SetMarg(self, xmarg, ymarg):
        self.set_x_st = xmarg
        self.set_y_st = ymarg
        self.set_y_end = ymarg

    def InitScale(self):        # scale position values
        self.sizew = self.set_sizew * self.pwidth
        self.sizeh = self.set_sizeh * self.pheight

        self.cx_st = self.set_cx_st * self.pwidth       # draw start position
        self.cy_st = self.set_cy_st * self.pheight

        self.x_mrg = self.set_x_mrg * self.pwidth         # calendar draw margins
        self.y_mrg = self.set_y_mrg * self.pheight
        self.y_end = self.set_y_end * self.pheight

    def DrawCal(self, DC, sel_lst=[]):
        self.DC = DC
        self.InitScale()

        self.DrawBorder()
        if self.hide_title is False:
            self.DrawMonth()

        self.Center()

        self.DrawGrid()
        self.GetRect()

        if self.show_weekend is True:       # highlight weekend dates
            self.SetWeekEnd()

        self.AddSelect(sel_lst)     # overrides the weekend highlight

        self.DrawSel()      # highlighted days
        self.DrawWeek()
        self.DrawNum()

    def AddSelect(self, list, cfont=None, cbackgrd = None):
        if cfont is None:
            cfont = self.sel_color      # font digit color
        if cbackgrd is None:
            cbackgrd = self.high_color     # select background color

        for val in list:
            self.cal_sel[val] = (cfont, cbackgrd)

    def DrawBorder(self):   # draw border around the outside of the main display rectangle
        brush = wxBrush(wxNamedColour(self.back_color), wxSOLID)
        self.DC.SetBrush(brush)
        self.DC.SetPen(wxPen(wxNamedColour(self.border_color), 1))

        if self.outer_border is True:
            rect = wxRect(self.cx_st, self.cy_st, self.sizew, self.sizeh)  # full display window area
            self.DC.DrawRectangle(rect.x, rect.y, rect.width, rect.height)

    def DrawNumVal(self):
        self.DrawNum()

# calculate the calendar days and offset position

    def SetCal(self, year, month):
        self.InitValues()       # reset initial values

        self.year = year
        self.month = month

        day = 1
        t = Date(year, month, day)
        dow = self.dow = t.day_of_week     # start day in month
        dim = self.dim = t.days_in_month   # number of days in month
        if self.cal_type == "NORMAL":
            start_pos = dow+1
        else:
            start_pos = dow

        self.st_pos = start_pos

        self.cal = []
        for i in range(start_pos):
            self.cal.append('')
        i = 1
        while i <= dim:
            self.cal.append(str(i))
            i = i + 1
        return start_pos

    def SetWeekEnd(self, font_color='BLACK', backgrd = 'LIGHT GREY'):
        date = 6 - int(self.dow)     # start day of first saturday
        while date <= self.dim:
            self.cal_sel[date] = (font_color, backgrd)  # Saturday
            date = date + 1
            if date <= self.dim:
                self.cal_sel[date] = (font_color, backgrd)      # Sunday
                date = date + 6
            else:
                date = date + 7

    def GetRect(self):      # get the display rectange list of the day grid
        cnt = 0
        for y in self.gridy[1:-1]:
            for x in self.gridx[:-1]:
                rect = wxRect(x, y, self.dl_w, self.dl_h)  # create rect region
                self.rg[cnt] = rect
                cnt = cnt + 1
        return self.rg

    def GetCal(self):
        return self.cal

    def GetOffset(self):
        return self.st_pos

    def DrawMonth(self):        # month and year title
        month = Month[self.month]

        sizef = 11
        if self.sizeh < _MIDSIZE:
            sizef = 10

        f = wxFont(sizef, self.font, wxNORMAL, self.bold)
        self.DC.SetFont(f)

        tw,th = self.DC.GetTextExtent(month)
        adjust = self.cx_st + (self.sizew-tw)/2
        self.DC.DrawText(month, adjust, self.cy_st + th)

        year = str(self.year)
        tw,th = self.DC.GetTextExtent(year)
        adjust =  self.sizew - tw - self.x_mrg

        self.title_offset = th * 2

        f = wxFont(sizef, self.font, wxNORMAL, self.bold)
        self.DC.SetFont(f)
        self.DC.DrawText(year, self.cx_st + adjust, self.cy_st + th)

    def DrawWeek(self):     # draw the week days
        width = self.gridx[1]-self.gridx[0]
        height = self.gridy[1] - self.gridy[0]
        rect_w = self.gridx[7]-self.gridx[0]

        f = wxFont(10, self.font, wxNORMAL, self.bold)      # initial font setting
        if self.week_auto == True:
            test_size = self.max_week_size      # max size
            test_day = ' Sun '
            while test_size > 2:
                f.SetPointSize(test_size)
                self.DC.SetFont(f)
                tw,th = self.DC.GetTextExtent(test_day)
                if tw < width and th < height:
                    break
                test_size = test_size - 1
        else:
            f.SetPointSize(self.week_size)   # set fixed size
            self.DC.SetFont(f)

        self.DC.SetTextForeground(wxNamedColour(self.week_font_color))

        cnt_x = 0
        cnt_y = 0

        brush = wxBrush(wxNamedColour(self.week_color), wxSOLID)
        self.DC.SetBrush(brush)
#        self.DC.DrawRectangle(self.gridx[0], self.gridy[0], rect_w+1, height)

        if self.cal_type == "NORMAL":
            cal_days = CalDays
        else:
            cal_days = BusCalDays

        for val in cal_days:
            day = AbrWeekday[val]
            if self.sizew < 200:
                day = day[0]
            dw,dh = self.DC.GetTextExtent(day)
            diffx = (width-dw)/2
            diffy = (height-dh)/2

            x = self.gridx[cnt_x]
            y = self.gridy[cnt_y]
            self.DC.DrawRectangle(self.gridx[cnt_x], self.gridy[0], width+1, height)
            self.DC.DrawText(day, x+diffx, y+diffy)
            cnt_x = cnt_x + 1

    def DrawNum(self):      # draw the day numbers
        f = wxFont(10, self.font, wxNORMAL, self.bold)      # initial font setting
        if self.num_auto == True:
            test_size = self.max_num_size      # max size
            test_day = ' 99 '
            while test_size > 2:
                f.SetPointSize(test_size)
                self.DC.SetFont(f)
                tw,th = self.DC.GetTextExtent(test_day)
                if tw < self.dl_w and th < self.dl_h:
                    sizef = test_size
                    break
                test_size = test_size - 1
        else:
            f.SetPointSize(self.num_size)   # set fixed size
            self.DC.SetFont(f)

        cnt_x = 0
        cnt_y = 1
        for val in self.cal:
            x = self.gridx[cnt_x]
            y = self.gridy[cnt_y]

            try:
                num_val = int(val)
                num_color = self.cal_sel[num_val][0]
            except:
                num_color = self.day_font_color

            self.DC.SetTextForeground(wxNamedColour(num_color))
            self.DC.SetFont(f)

            tw,th = self.DC.GetTextExtent(val)
            if self.num_align_horz == wxALIGN_CENTRE:
                adj_h = (self.dl_w - tw)/2
            elif self.num_align_horz == wxALIGN_RIGHT:
                adj_h = self.dl_w - tw
            else:
                adj_h = 0   # left alignment

            adj_h = adj_h + self.num_indent_horz

            if self.num_align_vert == wxALIGN_CENTRE:
                adj_v = (self.dl_h - th)/2
            elif self.num_align_horz == wxALIGN_RIGHT:
                adj_v = self.dl_h - th
            else:
                adj_v = 0   # left alignment

            adj_v = adj_v + self.num_indent_vert

            self.DC.DrawText(val, x+adj_h, y+adj_v)
            if cnt_x < 6:
                cnt_x = cnt_x + 1
            else:
                cnt_x = 0
                cnt_y = cnt_y + 1

    def Center(self):       # calculate the dimensions in the center of the drawing area
        bdw = self.x_mrg * 2
        bdh = self.y_mrg + self.y_end + self.title_offset

        self.dl_w = int((self.sizew-bdw)/7)
        self.dl_h = int((self.sizeh-bdh)/7)

        self.dl_th = int(self.dl_h*self.cal_week_scale)     # week title adjustment
        self.cwidth = self.dl_w * 7
        self.cheight = self.dl_h * 6 + self.dl_th

    def DrawSel(self):         # highlighted selected days
        for key in self.cal_sel.keys():
            sel_color = self.cal_sel[key][1]
            brush = wxBrush(wxNamedColour(sel_color), wxSOLID)
            self.DC.SetBrush(brush)

            if self.hide_grid is False:
                self.DC.SetPen(wxPen(wxNamedColour(self.grid_color), 0))
            else:
                self.DC.SetPen(wxPen(wxNamedColour(self.back_color), 0))
            nkey = key + self.st_pos -1
            rect = self.rg[nkey]
            self.DC.DrawRectangle(rect.x, rect.y, rect.width+1, rect.height+1)

    def DrawGrid(self):         # calculate and draw the grid lines
        self.DC.SetPen(wxPen(wxNamedColour(self.grid_color), 0))

        self.gridx = []
        self.gridy = []

        self.x_st = self.cx_st + self.x_mrg
        self.y_st = self.cy_st + self.y_mrg + self.title_offset     # start postion of draw

        x1 = self.x_st
        y1 = self.y_st

        y2 = y1 + self.cheight
        for i in range(8):
            if self.hide_grid is False:
                self.DC.DrawLine(x1, y1, x1, y2)
            self.gridx.append(x1)
            x1 = x1 + self.dl_w

        x1 = self.x_st
        y1 = self.y_st

        x2 = x1 + self.cwidth
        for i in range(8):
            if self.hide_grid is False:
                self.DC.DrawLine(x1, y1, x2, y1)
            self.gridy.append(y1)
            if i == 0:
                y1 = y1 + self.dl_th
            else:
                y1 = y1 + self.dl_h


class PrtCalDraw(CalDraw):
    def InitValues(self):
        self.rg = {}
        self.cal_sel = {}
        self.set_cx_st = 1.0        # start draw border location
        self.set_cy_st = 1.0

        self.set_y_mrg = 0.2      # draw offset position
        self.set_x_mrg = 0.2
        self.set_y_end = 0.2

    def SetPSize(self, pwidth, pheight):    # calculate the dimensions in the center of the drawing area
        self.pwidth = int(pwidth)/self.scale
        self.pheight = int(pheight)/self.scale

    def SetPreview(self, preview):
        self.preview = preview

class wxCalendar(wxWindow):
    def __init__(self, parent, id, pos=wxDefaultPosition, size=wxDefaultSize):
        wxWindow.__init__(self, parent, id, pos, size)

    # set the calendar control attributes

        self.grid_color = 'BLACK'
        self.back_color = 'WHITE'
        self.hide_grid = False
        self.sel_color = 'RED'
        self.hide_title = False
        self.show_weekend = False
        self.cal_type = "NORMAL"

        self.week_color = 'LIGHT GREY'
        self.week_font_color = 'BLACK'      # font colors

        self.select_list = []

        self.SetBackgroundColour(wxNamedColor(self.back_color))
        self.Connect(-1, -1, wxEVT_LEFT_DOWN, self.OnLeftEvent)
        self.Connect(-1, -1, wxEVT_LEFT_DCLICK, self.OnLeftDEvent)
        self.Connect(-1, -1, wxEVT_RIGHT_DOWN, self.OnRightEvent)
        self.Connect(-1, -1, wxEVT_RIGHT_DCLICK, self.OnRightDEvent)

        self.sel_key = None      #  last used by
        self.sel_lst = []        # highlighted selected days

        self.SetNow()       # default calendar for current month

        self.size = None
        self.set_day = None

        EVT_PAINT(self, self.OnPaint)
        EVT_SIZE(self, self.OnSize)

# control some of the main calendar attributes

    def HideTitle(self):
        self.hide_title = True

    def HideGrid(self):
        self.hide_grid = True

# determine the calendar rectangle click area and draw a selection

    def ProcessClick(self, event):
        self.x, self.y = event.GetX(), event.GetY()
        key = self.GetDayHit(self.x, self.y)
        self.SelectDay(key)

# tab mouse click events and process

    def OnLeftEvent(self, event):
        self.click = 'LEFT'
        self.shiftkey = event.ShiftDown()
        self.ctrlkey = event.ControlDown()
        self.ProcessClick(event)

    def OnLeftDEvent(self, event):
        self.click = 'DLEFT'
        self.ProcessClick(event)

    def OnRightEvent(self, event):
        self.click = 'RIGHT'
        self.ProcessClick(event)

    def OnRightDEvent(self, event):
        self.click = 'DRIGHT'
        self.ProcessClick(event)

    def SetSize(self, set_size):
        self.size = set_size

    def SetSelDay(self, sel):
        self.sel_lst = sel  # list of highlighted days

# get the current date

    def SetNow(self):
        dt = now()
        self.month = dt.month
        self.year = dt.year
        self.day = dt.day

# set the current day

    def SetCurrentDay(self):
        self.SetNow()
        self.set_day = self.day

# get the date, day, month, year set in calendar

    def GetDate(self):
        return self.day, self.month, self.year

    def GetDay(self):
        return self.day

    def GetMonth(self):
        return self.month

    def GetYear(self):
        return self.year

# set the day, month, and year

    def SetDayValue(self, day):
        self.set_day = day

    def SetMonth(self, month):
        if month >= 1 and month <= 12:
            self.month = month
        else:
            self.month = 1
        self.set_day = None

    def SetYear(self, year):
        self.year = year

# increment year and month

    def IncYear(self):
        self.year = self.year + 1
        self.set_day = None

    def DecYear(self):
        self.year = self.year - 1
        self.set_day = None

    def IncMonth(self):
        self.month = self.month + 1
        if self.month > 12:
            self.month = 1
            self.year = self.year + 1
        self.set_day = None

    def DecMonth(self):
        self.month = self.month - 1
        if self.month < 1:
            self.month = 12
            self.year = self.year - 1
        self.set_day = None

# test to see if the selection has a date and create event

    def TestDay(self, key):
        try:
            self.day = int(self.cal[key])
        except:
            return None
        if self.day == "":
            return None
        else:
            evt = wxPyCommandEvent(2100, self.GetId())
            evt.click, evt.day, evt.month, evt.year = self.click, self.day, self.month, self.year
            evt.shiftkey = self.shiftkey
            evt.ctrlkey = self.ctrlkey
            self.GetEventHandler().ProcessEvent(evt)

            self.set_day = self.day
            return key

# find the clicked area rectangle

    def GetDayHit(self, mx, my):
        for key in self.rg.keys():
            val = self.rg[key]
            ms_rect = wxRect(mx, my, 1, 1)
            if wxIntersectRect(ms_rect, val) is not None:
                result = self.TestDay(key)
                return result
        return None

# calendar drawing

    def SetWeekColor(self, font_color, week_color):     # set font and background color for week title
        self.week_font_color = font_color
        self.week_color = week_color

    def AddSelect(self, list, font_color, back_color):
        list_val = [list, font_color, back_color]
        self.select_list.append(list_val)

    def ShowWeekEnd(self):
        self.show_weekend = True    # highlight weekend

    def SetBusType(self):
        self.cal_type = "BUS"

    def OnSize(self, evt):
        self.Refresh(False)
        evt.Skip()

    def OnPaint(self, event):
        DC = wxPaintDC(self)
        self.DoDrawing(DC)

    def DoDrawing(self, DC):
        DC = wxPaintDC(self)
        DC.BeginDrawing()

        self.cal = cal = CalDraw(self)

        cal.grid_color = self.grid_color
        cal.back_color = self.back_color
        cal.hide_grid = self.hide_grid
        cal.grid_color = self.grid_color
        cal.hide_title = self.hide_title
        cal.show_weekend = self.show_weekend
        cal.cal_type = self.cal_type

        if self.size is None:
            size = self.GetClientSize()
        else:
            size = self.size

# drawing attributes

        cal.week_font_color = self.week_font_color
        cal.week_color = self.week_color

        cal.SetSize(size)
        cal.SetCal(self.year, self.month)
        for val in self.select_list:
            cal.AddSelect(val[0], val[1], val[2])

        cal.DrawCal(DC, self.sel_lst)

        self.rg = cal.GetRect()
        self.cal = cal.GetCal()
        self.st_pos = cal.GetOffset()
        self.ymax = DC.MaxY()

        if self.set_day != None:
            self.SetDay(self.set_day)
        DC.EndDrawing()

# draw the selection rectangle

    def DrawRect(self, key, color = 'BLACK', width = 0):
        if key == None:
            return
        DC = wxClientDC(self)
        DC.BeginDrawing()

        brush = wxBrush(wxColour(0, 0xFF, 0x80), wxTRANSPARENT)
        DC.SetBrush(brush)
        DC.SetPen(wxPen(wxNamedColour(color), width))

        rect = self.rg[key]
        DC.DrawRectangle(rect.x, rect.y, rect.width+1, rect.height+1)

        DC.EndDrawing()

# set the day selection

    def SetDay(self, day):
        day = day + self.st_pos - 1
        self.SelectDay(day)

    def SelectDay(self, key):
        sel_size = 1
        self.DrawRect(self.sel_key, self.back_color, sel_size)     # clear large selection
        if self.hide_grid is False:
            self.DrawRect(self.sel_key, self.grid_color)

        self.DrawRect(key, self.sel_color, sel_size)
        self.sel_key = key      # store last used by
        self.select_day = None

    def ClearDsp(self):
        self.Clear()

class CalenDlg(wxDialog):
    def __init__(self, parent, month=None, day = None, year=None):
        wxDialog.__init__(self, parent, -1, "Event Calendar", wxPyDefaultPosition, wxSize(280, 360))

    # set the calendar and attributes
        self.calend = wxCalendar(self, -1, wxPoint(20, 60), wxSize(240, 200))
        if month == None:
            self.calend.SetCurrentDay()
            start_month = self.calend.GetMonth()
            start_year = self.calend.GetYear()
        else:
            self.calend.month = start_month = month
            self.calend.year = start_year = year
            self.calend.SetDayValue(day)

        self.calend.HideTitle()
        self.ResetDisplay()

    # get month list from DateTime
        monthlist = GetMonthList()

    # select the month
        mID = NewId()
        self.date = wxComboBox(self, mID, Month[start_month], wxPoint(20, 20), wxSize(90, -1), monthlist, wxCB_DROPDOWN)
        EVT_COMBOBOX(self, mID, self.EvtComboBox)

    # alternate spin button to control the month
        mID = NewId()
        h = self.date.GetSize().height
        self.m_spin = wxSpinButton(self, mID, wxPoint(130, 20), wxSize(h*2, h), wxSP_VERTICAL)
        self.m_spin.SetRange(1, 12)
        self.m_spin.SetValue(start_month)

        EVT_SPIN(self, mID, self.OnMonthSpin)

    # spin button to control the year
        mID = NewId()
        self.dtext = wxTextCtrl(self, -1, str(start_year), wxPoint(160, 20), wxSize(60, -1))
        h = self.dtext.GetSize().height

        self.y_spin = wxSpinButton(self, mID, wxPoint(220, 20), wxSize(h*2, h), wxSP_VERTICAL)
        self.y_spin.SetRange(1980, 2010)
        self.y_spin.SetValue(start_year)

        EVT_SPIN(self, mID, self.OnYrSpin)

        self.Connect(self.calend.GetId(), -1, 2100, self.MouseClick)

        x_pos = 50
        y_pos = 280
        but_size = wxSize(60, 25)

        mID = NewId()
        wxButton(self, mID, ' Ok ', wxPoint(x_pos, y_pos), but_size)
        EVT_BUTTON(self, mID, self.OnOk)

        mID = NewId()
        wxButton(self, mID, ' Close ', wxPoint(x_pos + 120, y_pos), but_size)
        EVT_BUTTON(self, mID, self.OnCancel)

    def OnOk(self, event):
        self.EndModal(wxID_OK)

    def OnCancel(self, event):
        self.EndModal(wxID_CANCEL)

# log the mouse clicks
    def MouseClick(self, evt):
        self.month = evt.month
        self.result = [evt.click, str(evt.day), Month[evt.month], str(evt.year)]  # result click type and date

        if evt.click == 'DLEFT':
            self.EndModal(wxID_OK)

# month and year spin selection routines
    def OnMonthSpin(self, event):
        month = event.GetPosition()
        self.date.SetValue(Month[month])
        self.calend.SetMonth(month)
        self.calend.Refresh()

    def OnYrSpin(self, event):
        year = event.GetPosition()
        self.dtext.SetValue(str(year))
        self.calend.SetYear(year)
        self.calend.Refresh()

    def EvtComboBox(self, event):
        name = event.GetString()
        monthval = self.date.FindString(name)
        self.m_spin.SetValue(monthval+1)

        self.calend.SetMonth(monthval+1)
        self.ResetDisplay()

# set the calendar for highlighted days

    def ResetDisplay(self):
        month = self.calend.GetMonth()
        self.calend.Refresh()



